# pkgmgr-github

[![License](https://img.shields.io/badge/License-LGPL%203.0-blue.svg)](https://spdx.org/licenses/LGPL-3.0)
[![Build Status](https://travis-ci.org/kuwv/pkgmgr-github.svg?branch=master)](https://travis-ci.org/kuwv/pkgmgr-github)
[![codecov](https://codecov.io/gh/kuwv/pkgmgr-github/branch/master/graph/badge.svg)](https://codecov.io/gh/kuwv/pkgmgr-github)

## Overview

GitHub based package manager.

## Install

`pip install proman.common`
